// p145.mjs
import sqlite3 from 'sqlite3';
import { open } from 'sqlite';

const db = await open({
  filename: './my-northwind.sqlite',
  driver: sqlite3.Database
});

async function createCustomer (cust) {
  const query = 
  `INSERT INTO Customer (CompanyName, ContactName, City, Phone) 
   VALUES ($companyName, $contactName, $city, $phone)`;
  const result = await db.run(query, {
    $companyName: cust.companyName, 
    $contactName: cust.contactName,
    $city: cust.city,
    $phone: cust.phone
  });
  return result;
}

async function updateCustomerAddress (custId, newAddress) {
  const query = 
  `UPDATE Customer SET Address = $newAddress 
   WHERE id=$custId`;
  const result = await db.run(query, { 
    $custId: custId, $newAddress: newAddress 
  });
  return result;
}

const insResult = await createCustomer({
  companyName: 'MPI', contactName: 'Peter Chan',
  phone: '(853) 85996123', city: 'Macao'
});

// insResult.lastID gives the primary key 'id' auto-generated by sqlite
console.log('A new customer is created by SQL INSERT');
console.log('insResult:', insResult);

const custId = insResult.lastID;
const updResult = await updateCustomerAddress(custId, 
  "R. de Luís Gonzaga Gomes");

console.log('Update the address of the new customer');
console.log('updResult:', updResult);

const query = "SELECT * FROM Customer WHERE Id=" +updResult.lastID;
const peter = await db.get(query);
console.log(peter);

await db.close();